#
# start-end_fishing.R, 11 Dec 21
#
# Data from the CESAW dataset.
# https://arxiv.org/abs/2106.03679

library("plyr")


plot_mins=function(proj)
{
# st_cnt=count(subset(tf, project_key == proj)$start_min)
st_cnt=count(subset(tf, project_key == proj)$end_min)
plot(st_cnt, type="l",
     	yaxs="i",
     	ylim=c(0, 1.05*max(st_cnt$freq)),
	xlab="Minutes past the hour")

st_cnt=st_cnt[order(st_cnt$freq, decreasing=TRUE), ]
text(x=50, st_cnt$freq[60], labels=proj, col="blue")
d=sapply(1:10, function(X)
	 text(x=st_cnt$x[X], st_cnt$freq[X], labels=st_cnt$x[X], col="red", pos=3, offset=-0.03))
}

proj_start_end=function(proj, t_exp=0.25, bwd=0.25, ncol=6)
{
df=subset(tf, project_key == proj)
# plot(df$end_min, df$start_min)
# smoothScatter(df$end_min, df$start_min,
# 		nbin=60,
# 		bandwidth=bwd,
# 		colramp = colorRampPalette(c("red", "blue")),
# 		transformation = function(x) x^t_exp,
# 		xlab="End", ylab="Start")
# lines(c(0, 60), c(0, 60))

t=table(df$end_min, df$start_min)
# sqrt produces a visually more interesting plot than log or nothing
image(sqrt(t), col = heat.colors(ncol, rev=TRUE),
	xlab=paste0("End (fraction hour, project ", proj, ")"), ylab="Start")
}


par(pch="+")
par(bty="l")


tf=read.csv("CESAW_time_fact.csv", as.is=TRUE)

tf$task_actual_time_minutes=tf$time_log_delta_minutes
tf$task_actual_time_minutes=tf$time_log_delta_minutes
tf$task_actual_start_date=tf$time_log_start_date
tf$task_actual_complete_date=tf$time_log_end_date

tf=subset(tf, task_actual_time_minutes > 0)

# POSIXct has a weird strcuture that some library functions cannot
# handle, e.g., some plyr functions
tf$act_start_date_time=as.POSIXct(tf$task_actual_start_date, format="%m/%d/%Y %H:%M")
tf$act_start=as.integer(tf$act_start_date_time)
tf$start_min=(tf$act_start %% 3600) / 60
tf$act_end_date_time=as.POSIXct(tf$task_actual_complete_date, format="%m/%d/%Y %H:%M")
tf$act_end=as.integer(tf$act_end_date_time)
tf$end_min=(tf$act_end %% 3600) / 60

#  table(tf$isround)/nrow(tf)
#    FALSE      TRUE
#0.7045319 0.2954681

p95=subset(tf, project_key == 95)
p614=subset(tf, project_key == 614)
p615=subset(tf, project_key == 615)
p617=subset(tf, project_key == 617)

par(mfcol=c(2, 2))
plot(count(p95$start_min))
plot(count(p614$start_min))
plot(count(p615$start_min))
plot(count(p617$start_min))

top_t=c(419, 79, 458, 180, 456, 461, 460, 181, 184, 101, 613, 95, 614, 612, 617, 615)
par(mfcol=c(4, 4))
par(oma=c(3, 1, 0.4, 0.4))
par(mar=c(4.0, 1.45, 0.4, 0.4))

dum=sapply(top_t, plot_mins)

dev.copy(dev=png, file="cesaw-end_min_count.png")
dev.off()

par(mfcol=c(2, 2))

proj_start_end(95)
proj_start_end(614)
proj_start_end(615)
proj_start_end(617)

dev.copy(dev=png, file="cesaw-start_end_min.png")
dev.off()


